import 'package:flutter/material.dart';
import 'package:flutter_svg/flutter_svg.dart';
import 'package:storebounty_init/storebountyinit.dart';
import 'package:storebounty_onboading/constant/constants/constant.dart';
import 'package:storebounty_onboading/widget/custombutton.dart';
import 'package:storebounty_onboading/widget/styles/textstles.dart';

class OnboardingEntrySabo extends StatefulWidget {
  final List<dynamic> slidesData;
  final VoidCallback onGetStarted;
  const OnboardingEntrySabo({Key? key, required this.slidesData, required this.onGetStarted}) : super(key: key);

  @override
  State<OnboardingEntrySabo> createState() => _OnboardingEntrySaboState();
}

class _OnboardingEntrySaboState extends State<OnboardingEntrySabo> {
  var onBoardingData = [
    {
      "id": 1,
      "title": "Listen to your Cravings",
      "image": "slide1.svg",
      "description": "Browse our menu and order your favourite meal in-store",
      "buttonTxt": "Next"
    },
    {
      "id": 2,
      "title": "Pay online",
      "image": "slide2.svg",
      "description": "Pay the exact amount while placing what you ordered",
      "buttonTxt": "Next"
    },
    {
      "id": 3,
      "title": "Fast Delivery",
      "image": "slide3.svg",
      "description": "Fast delivery to your home, office and wherever you are",
      "buttonTxt": "Get started"
    }
  ];

  @override
  Widget build(BuildContext context) {
    return PageView(
      children: widget.slidesData
          .map<Widget>((e) => OnboardingScreen(onBoardingData: e, onGetStarted: widget.onGetStarted,))
          .toList(),
    );
  }
}

class OnboardingScreen extends StatefulWidget {
  final dynamic onBoardingData;
  final VoidCallback onGetStarted;
  const OnboardingScreen({Key? key, this.onBoardingData, required this.onGetStarted}) : super(key: key);

  @override
  State<OnboardingScreen> createState() => _OnboardingScreenState();
}

class _OnboardingScreenState extends State<OnboardingScreen> {
  Color? defaultColor;

  @override
  void initState() {
    getColor();
    super.initState();
  }

  getColor() async {
    var colorString = await StoreBountyInit.getStoreColor() ?? "#000000";
    defaultColor = Color(int.parse("0xff" + colorString.substring(1)));
    var currencySymbol = await StoreBountyInit.getCurrencySymbol();
    // currency = currencySymbol!;
    setState(() {});
  }

  @override
  Widget build(BuildContext context) {
    return Scaffold(
      body: Column(
        crossAxisAlignment: CrossAxisAlignment.center,
        mainAxisAlignment: MainAxisAlignment.center,
        children: [
          // SizedBox(height: 121,),
          Row(
            mainAxisAlignment: MainAxisAlignment.center,
            children: [
              Container(
                height: 280,
                width: 280,
                child: SvgPicture.asset(
                    "$kImagePath/${widget.onBoardingData['IMAGE']}"),
                decoration: BoxDecoration(),
              ),
            ],
          ),
          SizedBox(
            height: 41,
          ),
          Container(
            child: Row(
              mainAxisAlignment: MainAxisAlignment.center,
              children: [
                Container(
                  width: widget.onBoardingData['ID'] == 1 ? 36 : 6,
                  height: 3,
                  decoration: BoxDecoration(
                      color: widget.onBoardingData['ID'] == 1
                          ? defaultColor ?? Color(0xff000000)
                          : Color(0xffD9D9D9)),
                ),
                SizedBox(
                  width: 5,
                ),
                Container(
                  width: widget.onBoardingData['ID'] == 2 ? 36 : 6,
                  height: 3,
                  decoration: BoxDecoration(
                      color: widget.onBoardingData['ID'] == 2
                          ? defaultColor ?? Color(0xff000000)
                          : Color(0xffD9D9D9)),
                ),
                SizedBox(
                  width: 5,
                ),
                Container(
                  width: widget.onBoardingData['ID'] == 3 ? 36 : 6,
                  height: 3,
                  decoration: BoxDecoration(
                      color: widget.onBoardingData['ID'] == 3
                          ? defaultColor ?? Color(0xff000000)
                          : Color(0xffD9D9D9)),
                )
              ],
            ),
          ),
          SizedBox(
            height: 33,
          ),
          Container(
            child: Text(
              "${widget.onBoardingData['TITLE']}",
              style: Styles.h3(color: defaultColor ?? Color(0xff000000)),
            ),
          ),
          SizedBox(
            height: 18,
          ),
          Container(
            margin: EdgeInsets.symmetric(horizontal: 30),
            child: Text("${widget.onBoardingData['DESCRIPTION']}", textAlign: TextAlign.center,),
          ),
          SizedBox(
            height: 75,
          ),
          Container(
            margin: EdgeInsets.symmetric(horizontal: 24),
            child: CustomButton(
              text: '${widget.onBoardingData['BUTTONTXT']}',
              color: defaultColor ?? Color(0xff000000),
              onPressed: () {
                if (widget.onBoardingData['ID'] == 3) {
                  print("get started");
                  widget.onGetStarted();
                }
              },
            ),
          )
        ],
      ),
    );
  }
}
