import 'package:flutter/material.dart';
import 'package:storebounty_init/storebountyinit.dart';
import 'package:storebounty_onboading/widget/styles/colors.dart';
import 'package:storebounty_onboading/widget/styles/textstles.dart';

class SowetoSlide extends StatefulWidget {
  final dynamic slidesData;
  final VoidCallback? onBtnClick;
  final bool currentPosition;
  const SowetoSlide(
      {Key? key,
      required this.slidesData,
      this.onBtnClick,
      required this.currentPosition})
      : super(key: key);

  @override
  State<SowetoSlide> createState() => _SowetoSlideState();
}

class _SowetoSlideState extends State<SowetoSlide> {
  Color? defaultColor;

  @override
  void initState() {
    getColor();
    super.initState();
  }

  getColor() async {
    var colorString = await StoreBountyInit.getStoreColor() ?? "#000000";
    defaultColor = Color(int.parse("0xff" + colorString.substring(1)));
    var currencySymbol = await StoreBountyInit.getCurrencySymbol();
    // currency = currencySymbol!;
    setState(() {});
  }

  @override
  Widget build(BuildContext context) {
    return Scaffold(
      body: Container(
        child: Stack(
          children: [
            Positioned.fill(
                child: Container(
                    decoration: new BoxDecoration(
                      gradient: new LinearGradient(
                        end: const Alignment(0.0, -1),
                        begin: const Alignment(0.0, 0.6),
                        colors: <Color>[
                          defaultColor ?? Color(0xff000000),
                          defaultColor?.withOpacity(0.7) ??
                              Color(0xff000000).withOpacity(0.7),
                          Colors.black12.withOpacity(0.0)
                        ],
                      ),
                    ),
                    child: Row(
                      children: [
                        SizedBox(
                          width: 30,
                        ),
                        Container(
                          width: MediaQuery.of(context).size.width - 150,
                          child: Column(
                            mainAxisAlignment: MainAxisAlignment.end,
                            children: [
                              Text(
                                "${widget.slidesData['TITLE']}",
                                style: Styles.p0(
                                    fontSize: 32,
                                    fontWeight: FontWeight.w600,
                                    color: AppColors.whiteColor),
                              ),
                              Text(
                                  "${widget.slidesData['DESCRIPTION']}",
                                  style: Styles.p3(
                                      fontSize: 12,
                                      fontWeight: FontWeight.w400,
                                      color: AppColors.whiteColor)),
                              SizedBox(
                                height: 160,
                              )
                            ],
                          ),
                        ),
                      ],
                    ))),
            Positioned(
                bottom: 0,
                left: 0,
                right: 0,
                child: Container(
                  margin: EdgeInsets.symmetric(vertical: 10, horizontal: 10),
                  child: Row(
                    children: [
                      Expanded(
                        child: Container(
                          height: 115,
                          decoration: BoxDecoration(
                            borderRadius: BorderRadius.circular(32),
                            color: darken(defaultColor ?? Color(0xff000000),
                                amount: 0.2),
                          ),
                          child: Row(
                            children: [
                              SizedBox(
                                width: 30,
                              ),
                              SlidePositionIndicator(
                                currentPosition: widget.currentPosition,
                              ),
                              SlidePositionIndicator(
                                currentPosition: widget.currentPosition,
                              ),
                              SlidePositionIndicator(
                                currentPosition: widget.currentPosition,
                              ),
                              Spacer(),
                              GestureDetector(
                                onTap: widget.onBtnClick,
                                child: Container(
                                  height: 49,
                                  width: 140,
                                  decoration: BoxDecoration(
                                      color: AppColors.whiteColor,
                                      borderRadius: BorderRadius.circular(40)),
                                  child: Row(
                                    mainAxisAlignment: MainAxisAlignment.center,
                                    children: [
                                      Text("${widget.slidesData['BUTTONTXT']}"),
                                      SizedBox(
                                        width: 10,
                                      ),
                                      Icon(
                                        Icons.arrow_forward,
                                        size: 20,
                                      )
                                    ],
                                  ),
                                ),
                              ),
                              SizedBox(
                                width: 30,
                              ),
                            ],
                          ),
                        ),
                      ),
                    ],
                  ),
                ))
          ],
        ),
      ),
    );
  }

  Color darken(Color color, {double amount = 0.1}) {
    assert(amount >= 0 && amount <= 1, 'Amount should be between 0 and 1');

    final int red = (color.red * (1 - amount)).round();
    final int green = (color.green * (1 - amount)).round();
    final int blue = (color.blue * (1 - amount)).round();

    return Color.fromRGBO(red, green, blue, 1);
  }
}

class SlidePositionIndicator extends StatelessWidget {
  final bool? currentPosition;
  const SlidePositionIndicator({Key? key, this.currentPosition})
      : super(key: key);

  @override
  Widget build(BuildContext context) {
    return Container(
      child: Padding(
        padding: const EdgeInsets.all(2.0),
        child: Container(
          height: 6,
          width: 6,
          decoration:
              BoxDecoration(color: Colors.white, shape: BoxShape.circle),
        ),
      ),
      decoration: BoxDecoration(
          border: Border.all(
            width: 1,
            color: currentPosition == true ? Colors.white : Color(0xff1A2B3D),
          ),
          shape: BoxShape.circle),
    );
  }
}
